@@ -15,7 +15,7 @@
 #' }
 bhl_getauthortitles <- function(creatorid, as='table', key = NULL, ...) {
 
-  args <- bhlc(list(op = "GetAuthorTitles", apikey = check_key(key), format = as_f(as),
-                       creatorid = creatorid))
+  args <- bhlc(list(op = "GetAuthorTitles", apikey = check_key(key),
+                    format = as_f(as), creatorid = creatorid))
   bhl_GET(as, args, ...)
 }
