@@ -2,7 +2,8 @@
 #'
 #' @export
 #'
-#' @param type The type of identifier (doi, oclc, issn, isbn, lccn, ddc, nal, nlm, coden)
+#' @param type The type of identifier (doi, oclc, issn, isbn, lccn, ddc, nal,
+#' nlm, coden)
 #' @param value The identifier value
 #' @inheritParams bhl_getcollections
 #' @examples \dontrun{
@@ -12,9 +13,10 @@
 #' bhl_getpartbyidentifier('doi', '10.4039/Ent38406-12', as='list')
 #' }
 
-bhl_getpartbyidentifier <- function(type=NULL, value=NULL, as = "table", key = NULL, ...)
-{
-  args <- bhlc(list(op = "GetPartByIdentifier", apikey = check_key(key), format = as_f(as),
-                       type=type, value=value))
+bhl_getpartbyidentifier <- function(type=NULL, value=NULL, as = "table",
+                                    key = NULL, ...) {
+
+  args <- bhlc(list(op = "GetPartByIdentifier", apikey = check_key(key),
+                    format = as_f(as), type = type, value = value))
   bhl_GET(as, args, ...)
 }
