@@ -8,8 +8,8 @@
 #' bhl_getunpublisheditems('json')
 #' }
 
-bhl_getunpublisheditems <- function(as = "table", key = NULL, ...)
-{
-  args <- bhlc(list(op = "GetUnpublishedItems", apikey = check_key(key), format = as_f(as)))
+bhl_getunpublisheditems <- function(as = "table", key = NULL, ...) {
+  args <- bhlc(list(op = "GetUnpublishedItems", apikey = check_key(key),
+                    format = as_f(as)))
   bhl_GET(as, args, ...)
 }
