@@ -4,22 +4,22 @@ check_key <- function(x) {
 }
 
 bhl_GET <- function(as, args, ...){
-  out <- GET(bhl_url(), query = args, ...)
-  stop_for_status(out)
+  cli <- crul::HttpClient$new(url = bhl_url(), opts = list(...))
+  out <- cli$get(query = args)
+  out$raise_for_status()
+  tt <- out$parse("UTF-8")
   res <- switch(as,
-         xml = length(xml_children(xml_find_all(read_xml(content_utf8(out)), "//Result"))),
-         json = length(jsonlite::fromJSON(content_utf8(out))$Result),
-         list = length(jsonlite::fromJSON(content_utf8(out))$Result),
-         table = length(jsonlite::fromJSON(content_utf8(out))$Result))
+         xml = length(xml_children(xml_find_all(read_xml(tt),
+                                                "//Result"))),
+         json = length(jsonlite::fromJSON(tt)$Result),
+         list = length(jsonlite::fromJSON(tt)$Result),
+         table = length(jsonlite::fromJSON(tt)$Result))
   if (is.null(res) || res == 0) {
     stop("No results found", call. = FALSE)
   }
-  tt <- content_utf8(out)
   switch(as, json = tt, xml = tt, list = fjson(tt), table = todf(tt))
 }
 
-content_utf8 <- function(x) content(x, as = "text", encoding = "UTF-8")
-
 todf <- function(x){
   temp <- jsonlite::fromJSON(I(x), TRUE, flatten = TRUE)$Result
   if (is.character(temp)) {
@@ -28,7 +28,7 @@ todf <- function(x){
     tmp <- if (!is.null(names(temp))) {
       data.frame(bhlc(temp), stringsAsFactors = FALSE)
     } else {
-      do.call(rbind.fill, lapply(bhlc(temp), data.frame))
+      do.call(plyr::rbind.fill, lapply(bhlc(temp), data.frame))
     }
     tibble::as_data_frame(tmp)
   }
